clear all
close all

%ROIs = false;
ROIs = true;

pixel2nm = 104;
x_size = 3000;
y_size = 3000;
pixel_size = 104 / 10;

infile1 = ...
   'NewSample_Cell2_Label1_secondtry#0001-2016-4-19-16-11-13_Results.mat';
infile2 = 'Cell2_secondtry_label2#0001-2016-4-20-1-7-11_Results.mat';

results = 'results';
basefile = 'Cell2';
base = sprintf('%s/%s', results, basefile);

c = Clustering();
c.Plotting = false;

pc = PairCorr();
pc.Fig_ext = '';
pc.Lines = true;
pc.Results = results;
%pc.Rmax_axis = 500;

if ROIs
   pc.ROI_size = max(x_size, y_size);

   % Choose the ROIs
   [n_ROIs, RoI, Sigma_Reg] = c.getROI(infile1, x_size, y_size, infile2);
   saveas(gcf, sprintf('%s_ROIs.fig', base));
   print(sprintf('%s_ROIs.png', base), '-dpng');
   close all
else
   n_ROIs = 1;

   load(infile1);
%  Sigma_Reg = std(SRD.DriftCorrect_XYShift) .* pixel2nm;  %nm
%  if exist('Sigma_Reg', 'var') && isnan(Sigma_Reg)
      Sigma_Reg = [10, 10];
%  end

   RoI{1}.X1 = double(SRD.Results.X) .* pixel2nm;   % nm
   RoI{1}.Y1 = double(SRD.Results.Y) .* pixel2nm;   % nm
   RoI{1}.X1_STD = double(SRD.Results.X_STD) .* pixel2nm;   % nm
   RoI{1}.Y1_STD = double(SRD.Results.Y_STD) .* pixel2nm;   % nm

   load(infile2);
%  Sigma_Reg = std(SRD.DriftCorrect_XYShift) .* pixel2nm;  %nm
%  if exist('Sigma_Reg', 'var') && isnan(Sigma_Reg)
      Sigma_Reg = [10, 10];
%  end

   RoI{1}.X2 = double(SRD.Results.X) .* pixel2nm;   % nm
   RoI{1}.Y2 = double(SRD.Results.Y) .* pixel2nm;   % nm
   RoI{1}.X2_STD = double(SRD.Results.X_STD) .* pixel2nm;   % nm
   RoI{1}.Y2_STD = double(SRD.Results.Y_STD) .* pixel2nm;   % nm

   RoI{1}.ROI = [min([RoI{1}.X1; RoI{1}.X2]), ...
                 min([RoI{1}.Y1; RoI{1}.Y2]), ...
                 max([RoI{1}.X1; RoI{1}.X2]), ...
                 max([RoI{1}.Y1; RoI{1}.Y2])];
end
save(sprintf('%s_ROIs.mat', base), 'n_ROIs', 'RoI', 'Sigma_Reg');

ROIs1 = cell(n_ROIs, 1);
ROIs2 = cell(n_ROIs, 1);
ROIs  = cell(n_ROIs, 1);
for i = 1 : n_ROIs
   fprintf('ROI %d\n\n', i);

   % Label 1 coordinates for ROI i
   X1 = RoI{i}.X1;
   Y1 = RoI{i}.Y1;
   X1_STD = RoI{i}.X1_STD;
   Y1_STD = RoI{i}.Y1_STD;

   % Label 2 coordinates for ROI i
   X2 = RoI{i}.X2;
   Y2 = RoI{i}.Y2;
   X2_STD = RoI{i}.X2_STD;
   Y2_STD = RoI{i}.Y2_STD;

   % Combined coordinates for ROI i
   XY1 = [X1, Y1];
   XY2 = [X2, Y2];

   % Cell array for auto-correlation on label 1 for ROI i
   ROIs1{i}.ROI = RoI{i}.ROI;
   ROIs1{i}.XY1 = XY1;

   % Cell array for auto-correlation on label 2 for ROI i
   ROIs2{i}.ROI = RoI{i}.ROI;
   ROIs2{i}.XY1 = XY2;

   % Cell array for cross-correlation between labels 1 and 2 for ROI i
   ROIs{i}.ROI = RoI{i}.ROI;
   ROIs{i}.XY1 = XY1;
   ROIs{i}.XY2 = XY2;

   pc.ROI = [RoI{i}.ROI(1), RoI{i}.ROI(3), ...
             RoI{i}.ROI(2) - RoI{i}.ROI(1), RoI{i}.ROI(4) - RoI{i}.ROI(3)];

   % Auto-correlation on label 1 for ROI i
   base_file = sprintf('%s_ROI%d_L1',  basefile, i);
   results_pac1 = pc.pair_correlation(pixel_size, base_file, XY1)

   % Auto-correlation on label 2 for ROI i
   base_file = sprintf('%s_ROI%d_L2',  basefile, i);
   results_pac2 = pc.pair_correlation(pixel_size, base_file, XY2)

   % Cross-correlation between labels 1 and 2 for ROI i
   base_file = sprintf('%s_ROI%d',  basefile, i);
   results_pcc  = pc.pair_correlation(pixel_size, base_file, XY1, XY2)
end

% Auto-correlation on label 1 over all ROIs
base_file = sprintf('%s_L1', basefile);
resultsRC_pac1 = ...
   pc.pair_correlation_ROIcombined(pixel_size, base_file, 1, n_ROIs, ROIs1)

% Auto-correlation on label 2 over all ROIs
base_file = sprintf('%s_L2', basefile);
resultsRC_pac2 = ...
   pc.pair_correlation_ROIcombined(pixel_size, base_file, 1, n_ROIs, ROIs2)

% Cross-correlation between labels 1 and 2 over all ROIs
resultsRC_pcc = ...
   pc.pair_correlation_ROIcombined(pixel_size, basefile, 2, n_ROIs, ROIs)
